@@ -1,7 +1,13 @@
+/*
+ * SPDX-FileCopyrightText: 2014-2015 David Rosca <nowrep@gmail.com>
+ *
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+ */
+
 #ifndef AUTOTESTS_H
 #define AUTOTESTS_H
 
-#include <QtTest/QTest>
+#include <QTest>
 #include <QSignalSpy>
 #include <QProcess>
 #include <QDBusMessage>
@@ -23,7 +29,6 @@ public:
 namespace Autotests
 {
 
-bool isBluez5Running();
 void registerMetatypes();
 void verifyPropertiesChangedSignal(const QSignalSpy &spy, const QString &propertyName, const QVariant &propertyValue);
 
