@@ -1,23 +1,9 @@
 /*
  * BluezQt - Asynchronous Bluez wrapper library
  *
- * Copyright (C) 2014 David Rosca <nowrep@gmail.com>
+ * SPDX-FileCopyrightText: 2014 David Rosca <nowrep@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #ifndef BLUEZQT_DEVICE_P_H
@@ -42,7 +28,7 @@ class DevicePrivate : public QObject
     Q_OBJECT
 
 public:
-    explicit DevicePrivate(const QString &path, const QVariantMap &properties, AdapterPtr adapter);
+    explicit DevicePrivate(const QString &path, const QVariantMap &properties, const AdapterPtr &adapter);
 
     void init(const QVariantMap &properties);
 
@@ -53,6 +39,7 @@ public:
     void propertiesChanged(const QString &interface, const QVariantMap &changed, const QStringList &invalidated);
     void namePropertyChanged(const QString &value);
     void aliasPropertyChanged(const QString &value);
+    void addressPropertyChanged(const QString &value);
     void classPropertyChanged(quint32 value);
 
     QWeakPointer<Device> q;
@@ -73,8 +60,10 @@ public:
     bool m_connected;
     QStringList m_uuids;
     QString m_modalias;
+    BatteryPtr m_battery;
     InputPtr m_input;
     MediaPlayerPtr m_mediaPlayer;
+    MediaTransportPtr m_mediaTransport;
     AdapterPtr m_adapter;
 };
 
