@@ -1,28 +1,15 @@
 /*
  * BluezQt - Asynchronous Bluez wrapper library
  *
- * Copyright (C) 2014 David Rosca <nowrep@gmail.com>
+ * SPDX-FileCopyrightText: 2014 David Rosca <nowrep@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "declarativedevicesmodel.h"
 #include "declarativemanager.h"
 #include "declarativeadapter.h"
+#include "declarativebattery.h"
 #include "declarativedevice.h"
 #include "declarativemediaplayer.h"
 
@@ -52,6 +39,7 @@ QHash<int, QByteArray> DeclarativeDevicesModel::roleNames() const
     roles[DeviceRole] = QByteArrayLiteral("Device");
     roles[AdapterRole] = QByteArrayLiteral("Adapter");
     roles[MediaPlayerRole] = QByteArrayLiteral("MediaPlayer");
+    roles[BatteryRole] = QByteArrayLiteral("Battery");
 
     return roles;
 }
@@ -76,8 +64,13 @@ QVariant DeclarativeDevicesModel::data(const QModelIndex &index, int role) const
         if (DeclarativeDevice *device = m_manager->declarativeDeviceFromPtr(dev)) {
             return QVariant::fromValue(device->mediaPlayer());
         }
-        // fallthrough
-    default:
-        return QSortFilterProxyModel::data(index, role);
+        break;
+    case BatteryRole:
+        if (DeclarativeDevice *device = m_manager->declarativeDeviceFromPtr(dev)) {
+            return QVariant::fromValue(device->battery());
+        }
+        break;
     }
+
+    return QSortFilterProxyModel::data(index, role);
 }
