@@ -1,23 +1,9 @@
 /*
  * BluezQt - Asynchronous Bluez wrapper library
  *
- * Copyright (C) 2014-2015 David Rosca <nowrep@gmail.com>
+ * SPDX-FileCopyrightText: 2014-2015 David Rosca <nowrep@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "manager_p.h"
@@ -29,8 +15,6 @@
 #include "debug.h"
 #include "utils.h"
 
-#include <QDBusReply>
-#include <QDBusConnection>
 #include <QDBusServiceWatcher>
 
 namespace BluezQt
@@ -42,7 +26,6 @@ ManagerPrivate::ManagerPrivate(Manager *parent)
     , m_dbusObjectManager(nullptr)
     , m_bluezAgentManager(nullptr)
     , m_bluezProfileManager(nullptr)
-    , m_usableAdapter(0)
     , m_initialized(false)
     , m_bluezRunning(false)
     , m_loaded(false)
@@ -82,6 +65,13 @@ void ManagerPrivate::init()
 
     QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(DBusConnection::orgBluez().asyncCall(call));
     connect(watcher, &QDBusPendingCallWatcher::finished, this, &ManagerPrivate::nameHasOwnerFinished);
+
+    DBusConnection::orgBluez().connect(Strings::orgBluez(),
+                                       QString(),
+                                       Strings::orgFreedesktopDBusProperties(),
+                                       QStringLiteral("PropertiesChanged"),
+                                       this,
+                                       SLOT(propertiesChanged(QString,QVariantMap,QStringList)));
 }
 
 void ManagerPrivate::nameHasOwnerFinished(QDBusPendingCallWatcher *watcher)
@@ -217,7 +207,7 @@ void ManagerPrivate::clear()
 
 AdapterPtr ManagerPrivate::findUsableAdapter() const
 {
-    Q_FOREACH (AdapterPtr adapter, m_adapters) {
+    for (AdapterPtr adapter : qAsConst(m_adapters)) {
         if (adapter->isPowered()) {
             return adapter;
         }
@@ -261,9 +251,16 @@ void ManagerPrivate::interfacesAdded(const QDBusObjectPath &objectPath, const QV
         }
     }
 
-    Q_FOREACH (DevicePtr device, m_devices.values()) {
-        if (path.startsWith(device->ubi())) {
-            device->d->interfacesAdded(path, interfaces);
+    for (auto it = m_adapters.cbegin(); it != m_adapters.cend(); ++it) {
+        if (path.startsWith(it.value()->ubi())) {
+            it.value()->d->interfacesAdded(path, interfaces);
+            break;
+        }
+    }
+
+    for (auto it = m_devices.cbegin(); it != m_devices.cend(); ++it) {
+        if (path.startsWith(it.value()->ubi())) {
+            it.value()->d->interfacesAdded(path, interfaces);
             break;
         }
     }
@@ -273,7 +270,7 @@ void ManagerPrivate::interfacesRemoved(const QDBusObjectPath &objectPath, const
 {
     const QString &path = objectPath.path();
 
-    Q_FOREACH (const QString &interface, interfaces) {
+    for (const QString &interface : interfaces) {
         if (interface == Strings::orgBluezAdapter1()) {
             removeAdapter(path);
         } else if (interface == Strings::orgBluezDevice1()) {
@@ -281,9 +278,16 @@ void ManagerPrivate::interfacesRemoved(const QDBusObjectPath &objectPath, const
         }
     }
 
-    Q_FOREACH (DevicePtr device, m_devices.values()) {
-        if (path.startsWith(device->ubi())) {
-            device->d->interfacesRemoved(path, interfaces);
+    for (auto it = m_adapters.cbegin(); it != m_adapters.cend(); ++it) {
+        if (path.startsWith(it.value()->ubi())) {
+            it.value()->d->interfacesRemoved(path, interfaces);
+            break;
+        }
+    }
+
+    for (auto it = m_devices.cbegin(); it != m_devices.cend(); ++it) {
+        if (path.startsWith(it.value()->ubi())) {
+            it.value()->d->interfacesRemoved(path, interfaces);
             break;
         }
     }
@@ -374,7 +378,8 @@ void ManagerPrivate::removeAdapter(const QString &adapterPath)
     }
 
     // Make sure we always remove all devices before removing the adapter
-    Q_FOREACH (const DevicePtr &device, adapter->devices()) {
+    const auto devices = adapter->devices();
+    for (const DevicePtr &device : devices) {
         removeDevice(device->ubi());
     }
 
@@ -424,6 +429,26 @@ void ManagerPrivate::setUsableAdapter(const AdapterPtr &adapter)
     }
 }
 
+void ManagerPrivate::propertiesChanged(const QString &interface, const QVariantMap &changed, const QStringList &invalidated)
+{
+    // Cut anything after device path to forward it to Device to handle
+    const QString path = message().path().section(QLatin1Char('/'), 0, 4);
+
+    QTimer::singleShot(0, this, [=]() {
+        AdapterPtr adapter = m_adapters.value(path);
+        if (adapter) {
+            adapter->d->propertiesChanged(interface, changed, invalidated);
+            return;
+        }
+        DevicePtr device = m_devices.value(path);
+        if (device) {
+            device->d->propertiesChanged(interface, changed, invalidated);
+            return;
+        }
+        qCDebug(BLUEZQT) << "Unhandled property change" << interface << changed << invalidated;
+    });
+}
+
 void ManagerPrivate::dummy()
 {
 }
