@@ -1,36 +1,19 @@
 /*
  * BluezQt - Asynchronous Bluez wrapper library
  *
- * Copyright (C) 2014 David Rosca <nowrep@gmail.com>
+ * SPDX-FileCopyrightText: 2014 David Rosca <nowrep@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "obextransfer.h"
 #include "obextransfer_p.h"
-#include "obexsession.h"
-#include "obexsession_p.h"
 #include "pendingcall.h"
+#include "obexmanager.h"
+#include "obexsession.h"
 #include "utils.h"
 #include "macros.h"
 
-#include "obextransfer1.h"
-#include "dbusproperties.h"
-
 namespace BluezQt
 {
 
@@ -50,14 +33,25 @@ static ObexTransfer::Status stringToStatus(const QString &status)
     return ObexTransfer::Unknown;
 }
 
-ObexTransferPrivate::ObexTransferPrivate(const QString &path)
+ObexTransferPrivate::ObexTransferPrivate(const QString &path, const QVariantMap &properties)
     : QObject()
-    , m_dbusProperties(0)
+    , m_dbusProperties(nullptr)
+    , m_status(ObexTransfer::Error)
+    , m_time(0)
+    , m_size(0)
+    , m_transferred(0)
+    , m_suspendable(false)
 {
     m_bluezTransfer = new BluezTransfer(Strings::orgBluezObex(), path, DBusConnection::orgBluezObex(), this);
+
+    if (Instance::obexManager()) {
+        connect(Instance::obexManager(), &ObexManager::sessionRemoved, this, &ObexTransferPrivate::sessionRemoved);
+    }
+
+    init(properties);
 }
 
-void ObexTransferPrivate::init()
+void ObexTransferPrivate::init(const QVariantMap &properties)
 {
     m_dbusProperties = new DBusProperties(Strings::orgBluezObex(), m_bluezTransfer->path(),
                                           DBusConnection::orgBluezObex(), this);
@@ -65,35 +59,14 @@ void ObexTransferPrivate::init()
     connect(m_dbusProperties, &DBusProperties::PropertiesChanged,
             this, &ObexTransferPrivate::propertiesChanged, Qt::QueuedConnection);
 
-    const QDBusPendingReply<QVariantMap> &call = m_dbusProperties->GetAll(Strings::orgBluezObexTransfer1());
-    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(call, this);
-    connect(watcher, &QDBusPendingCallWatcher::finished, this, &ObexTransferPrivate::getPropertiesFinished);
-}
-
-void ObexTransferPrivate::getPropertiesFinished(QDBusPendingCallWatcher *watcher)
-{
-    const QDBusPendingReply<QVariantMap> &reply = *watcher;
-    watcher->deleteLater();
-
-    if (reply.isError()) {
-        Q_EMIT initError(reply.error().message());
-        return;
-    }
-
-    const QVariantMap &properties = reply.value();
-
+    // Init properties
     m_status = stringToStatus(properties.value(QStringLiteral("Status")).toString());
-    m_session = new ObexSession(properties.value(QStringLiteral("Session")).value<QDBusObjectPath>().path());
     m_name = properties.value(QStringLiteral("Name")).toString();
     m_type = properties.value(QStringLiteral("Type")).toString();
     m_time = properties.value(QStringLiteral("Time")).toUInt();
     m_size = properties.value(QStringLiteral("Size")).toUInt();
     m_transferred = properties.value(QStringLiteral("Transferred")).toUInt();
     m_fileName = properties.value(QStringLiteral("Filename")).toString();
-
-    m_session->d->init();
-    connect(m_session->d, &ObexSessionPrivate::initFinished, this, &ObexTransferPrivate::initFinished);
-    connect(m_session->d, &ObexSessionPrivate::initError, this, &ObexTransferPrivate::initError);
 }
 
 void ObexTransferPrivate::propertiesChanged(const QString &interface, const QVariantMap &changed, const QStringList &invalidated)
@@ -110,11 +83,7 @@ void ObexTransferPrivate::propertiesChanged(const QString &interface, const QVar
         const QString &property = i.key();
 
         if (property == QLatin1String("Status")) {
-            ObexTransfer::Status changedStatus = stringToStatus(value.toString());
-            if (m_status != changedStatus) {
-                m_status = changedStatus;
-                Q_EMIT q.data()->statusChanged(m_status);
-            }
+            PROPERTY_CHANGED2(m_status, stringToStatus(value.toString()), statusChanged);
         } else if (property == QLatin1String("Transferred")) {
             PROPERTY_CHANGED(m_transferred, toUInt, transferredChanged);
         } else if (property == QLatin1String("Filename")) {
@@ -123,9 +92,22 @@ void ObexTransferPrivate::propertiesChanged(const QString &interface, const QVar
     }
 }
 
-ObexTransfer::ObexTransfer(const QString &path, QObject *parent)
-    : QObject(parent)
-    , d(new ObexTransferPrivate(path))
+void ObexTransferPrivate::sessionRemoved(const ObexSessionPtr &session)
+{
+    if (!m_bluezTransfer->path().startsWith(session->objectPath().path())) {
+        return;
+    }
+
+    // Change status to Error if org.bluez.obex crashes
+    if (m_status != ObexTransfer::Complete && m_status != ObexTransfer::Error) {
+        m_status = ObexTransfer::Error;
+        Q_EMIT q.lock()->statusChanged(m_status);
+    }
+}
+
+ObexTransfer::ObexTransfer(const QString &path, const QVariantMap &properties)
+    : QObject()
+    , d(new ObexTransferPrivate(path, properties))
 {
 }
 
@@ -149,11 +131,6 @@ ObexTransfer::Status ObexTransfer::status() const
     return d->m_status;
 }
 
-ObexSession *ObexTransfer::session() const
-{
-    return d->m_session;
-}
-
 QString ObexTransfer::name() const
 {
     return d->m_name;
@@ -186,7 +163,7 @@ QString ObexTransfer::fileName() const
 
 bool ObexTransfer::isSuspendable() const
 {
-    return false;
+    return d->m_suspendable;
 }
 
 PendingCall *ObexTransfer::cancel()
