@@ -1,23 +1,9 @@
 /*
  * BluezQt - Asynchronous Bluez wrapper library
  *
- * Copyright (C) 2015 David Rosca <nowrep@gmail.com>
+ * SPDX-FileCopyrightText: 2015 David Rosca <nowrep@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "rfkill.h"
@@ -210,8 +196,8 @@ void Rfkill::updateRfkillDevices()
             break;
 
         case RFKILL_OP_CHANGE_ALL:
-            Q_FOREACH (quint32 id, m_devices.keys()) {
-                m_devices[id] = getState(event);
+            for (auto it = m_devices.begin(); it != m_devices.end(); ++it) {
+                it.value() = getState(event);
             }
             break;
 
@@ -223,7 +209,7 @@ void Rfkill::updateRfkillDevices()
     // Update global state
     m_state = Unknown;
 
-    Q_FOREACH (State state, m_devices) { // krazy:exclude=foreach
+    for (State state : qAsConst(m_devices)) {
         Q_ASSERT(state != Unknown);
 
         if (m_state == Unknown) {
